@@ -117,6 +117,7 @@ dict_Materials = {
     "Al2TiO5_all": ["Al2TiO5_all", [3.60500,	9.44500,	9.65300, 90.0, 90, 90], "no"],
     "Al2TiO5": ["Al2TiO5", [3.60500,	9.44500, 9.65300, 90.0, 90, 90], "63"],
     "Al2TiO5_new": ["Al2TiO5_new", [3.595,	9.473,	9.677, 90.0, 90, 90], "63"],
+    "Li2VOPO4": ["Li2VOPO4", [7.096, 7.811, 7.101, 90.17, 116.55, 90.72], "no"],
 }
 
 dict_Materials_short = {
@@ -283,6 +284,7 @@ CCD_CALIBRATION_PARAMETERS = ["dd", "xcen", "ycen", "xbet", "xgam", "pixelsize",
 dict_CCD = {
     "MARCCD165": ((2048, 2048), 0.079142, 65535, "no", 4096, "uint16", "MAR Research 165 mm now rayonix", "mccd", ),
     "sCMOS": [(2018, 2016), 0.0734, 65535, "no", 3828, "uint16", "file as produced by sCMOS camera with checked fliplr transform. CCD parameters read from tif header by fabio", "tif"],
+    "cor": [(2018, 2016), 0.0734, 65535, "no", 3828, "uint16", "file as produced by sCMOS camera with checked fliplr transform. CCD parameters read from tif header by fabio", "tif"],
     "sCMOS_fliplr": [(2018, 2016), 0.0734, 65535, "sCMOS_fliplr", 3828, "uint16", "binned 2x2, CCD parameters read from tif header by fabio", "tif"],
     "sCMOS_fliplr_16M": [(2 * 2018, 2 * 2016), 0.0734 / 2.0, 65535, "sCMOS_fliplr", 3828, "uint16", "binned 1x1, CCD parameters binned 1x1 read from tif header by fabio ", "tif"],
     "sCMOS_16M": [(2 * 2018, 2 * 2016), 0.0734 / 2.0, 65535, "no", 3828, "uint16", "binned 1x1, CCD parameters binned 1x1 read from tif header by fabio ", "tif"],
