@@ -259,6 +259,8 @@ def genHKL_np(listn, Extinc):
 
     .. note:: node [0,0,0] is excluded
     """
+    # print(Extinc)
+    # print(listn)
     if listn is None:
         raise ValueError("hkl ranges are undefined")
 
@@ -1763,7 +1765,7 @@ def SimulateLaue(grain, emin, emax, detectorparameters, kf_direction=DEFAULT_TOP
     """
 
     if detectordiameter is None:
-        DETECTORDIAMETER = pixelsize * dim[0] * 2
+        DETECTORDIAMETER = pixelsize * dim[0] #TODO * 2
     else:
         DETECTORDIAMETER = detectordiameter
 
@@ -1841,7 +1843,7 @@ def SimulateLaue_full_np(grain, emin, emax, detectorparameters, kf_direction=DEF
     """
 
     if detectordiameter is None:
-        DETECTORDIAMETER = pixelsize * dim[0] * 2.0
+        DETECTORDIAMETER = pixelsize * dim[0] #TODO * 2.0
     else:
         DETECTORDIAMETER = detectordiameter
     # use DEFAULT_TOP_GEOMETRY <=> kf_direction = 'Z>0'
